@@ -30,7 +30,6 @@
 #include "nautilus-global-preferences.h"
 #include "nautilus-icon-factory-private.h"
 #include "nautilus-icon-factory.h"
-#include "nautilus-theme.h"
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-string.h>
@@ -56,6 +55,9 @@
 /* Should never be a reasonable actual mtime */
 #define INVALID_MTIME 0
 
+/* Cool-off period between last file modification time and thumbnail creation */
+#define THUMBNAIL_CREATION_DELAY_SECS 3
+
 static gpointer thumbnail_thread_start (gpointer data);
 
 /* structure used for making thumbnails, associating a uri with where the thumbnail is to be stored */
@@ -176,27 +178,28 @@ thumbnail_thread_starter_cb (gpointer data)
 }
 
 void
-nautilus_update_thumbnail_file_renamed (const char *old_file_uri, const char *new_file_uri)
+nautilus_update_thumbnail_file_copied (const char *source_file_uri,
+				       const char *destination_file_uri)
 {
 	char *old_thumbnail_path;
 	GdkPixbuf *pixbuf;
 	GnomeVFSFileInfo *file_info;
 	GnomeThumbnailFactory *factory;
 	
-	old_thumbnail_path = gnome_thumbnail_path_for_uri (old_file_uri, GNOME_THUMBNAIL_SIZE_NORMAL);
+	old_thumbnail_path = gnome_thumbnail_path_for_uri (source_file_uri, GNOME_THUMBNAIL_SIZE_NORMAL);
 	if (old_thumbnail_path != NULL &&
 	    g_file_test (old_thumbnail_path, G_FILE_TEST_EXISTS)) {
 		file_info = gnome_vfs_file_info_new ();
-		if (gnome_vfs_get_file_info (new_file_uri,
+		if (gnome_vfs_get_file_info (destination_file_uri,
 					     file_info,
 					     GNOME_VFS_FILE_INFO_DEFAULT) == GNOME_VFS_OK) {
 			pixbuf = gdk_pixbuf_new_from_file (old_thumbnail_path, NULL);
 			
-			if (pixbuf && gnome_thumbnail_has_uri (pixbuf, old_file_uri)) {
+			if (pixbuf && gnome_thumbnail_has_uri (pixbuf, source_file_uri)) {
 				factory = nautilus_icon_factory_get_thumbnail_factory ();
 				gnome_thumbnail_factory_save_thumbnail (factory,
 									pixbuf,
-									new_file_uri,
+									destination_file_uri,
 									file_info->mtime);
 				g_object_unref (factory);
 			}
@@ -205,7 +208,6 @@ nautilus_update_thumbnail_file_renamed (const char *old_file_uri, const char *ne
 				g_object_unref (pixbuf);
 			}
 			
-			unlink (old_thumbnail_path);
 		}
 		gnome_vfs_file_info_unref (file_info);
 	}
@@ -213,26 +215,31 @@ nautilus_update_thumbnail_file_renamed (const char *old_file_uri, const char *ne
 	g_free (old_thumbnail_path);
 }
 
-void 
-nautilus_remove_thumbnail_for_file (const char *old_file_uri)
+void
+nautilus_update_thumbnail_file_renamed (const char *source_file_uri,
+					const char *destination_file_uri)
 {
-	char *old_thumbnail_path;
+	nautilus_update_thumbnail_file_copied (source_file_uri, destination_file_uri);
+	nautilus_remove_thumbnail_for_file (source_file_uri);
+}
+
+void 
+nautilus_remove_thumbnail_for_file (const char *file_uri)
+{
+	char *thumbnail_path;
 	
-	old_thumbnail_path = gnome_thumbnail_path_for_uri (old_file_uri, GNOME_THUMBNAIL_SIZE_NORMAL);
-	if (old_thumbnail_path != NULL) {
-		unlink (old_thumbnail_path);
+	thumbnail_path = gnome_thumbnail_path_for_uri (file_uri, GNOME_THUMBNAIL_SIZE_NORMAL);
+	if (thumbnail_path != NULL) {
+		unlink (thumbnail_path);
 	}
-	g_free (old_thumbnail_path);
+	g_free (thumbnail_path);
 }
 
 void
 nautilus_thumbnail_frame_image (GdkPixbuf **pixbuf)
 {
 	GdkPixbuf *pixbuf_with_frame, *frame;
-	gboolean got_frame_offsets;
-	char *frame_offset_str;
 	int left_offset, top_offset, right_offset, bottom_offset;
-	char c;
 		
 	/* The pixbuf isn't already framed (i.e., it was not made by
 	 * an old Nautilus), so we must embed it in a frame.
@@ -243,22 +250,10 @@ nautilus_thumbnail_frame_image (GdkPixbuf **pixbuf)
 		return;
 	}
 	
-	got_frame_offsets = FALSE;
-	frame_offset_str = nautilus_theme_get_theme_data ("thumbnails", "FRAME_OFFSETS");
-	if (frame_offset_str != NULL) {
-		if (sscanf (frame_offset_str, " %d , %d , %d , %d %c",
-			    &left_offset, &top_offset, &right_offset, &bottom_offset, &c) == 4) {
-			got_frame_offsets = TRUE;
-		}
-		g_free (frame_offset_str);
-	}
-	if (!got_frame_offsets) {
-		/* use nominal values since the info in the theme couldn't be found */
-		left_offset = 3;
-		top_offset = 3;
-		right_offset = 6;
-		bottom_offset = 6;
-	}
+	left_offset = 3;
+	top_offset = 3;
+	right_offset = 6;
+	bottom_offset = 6;
 	
 	pixbuf_with_frame = eel_embed_image_in_frame
 		(*pixbuf, frame,
@@ -509,6 +504,7 @@ thumbnail_thread_start (gpointer data)
 	NautilusThumbnailInfo *info = NULL;
 	GdkPixbuf *pixbuf;
 	time_t current_orig_mtime = 0;
+	time_t current_time;
 
 	/* We loop until there are no more thumbails to make, at which point
 	   we exit the thread. */
@@ -564,6 +560,21 @@ thumbnail_thread_start (gpointer data)
 #endif
 		pthread_mutex_unlock (&thumbnails_mutex);
 
+		time (&current_time);
+
+		/* Don't try to create a thumbnail if the file was modified recently.
+		   This prevents constant re-thumbnailing of changing files. */ 
+		if (current_time < current_orig_mtime + THUMBNAIL_CREATION_DELAY_SECS &&
+		    current_time >= current_orig_mtime) {
+#ifdef DEBUG_THUMBNAILS
+			g_message ("(Thumbnail Thread) Skipping: %s\n",
+				   info->image_uri);
+#endif
+			/* Reschedule thumbnailing via a change notification */
+			g_timeout_add (1000, thumbnail_thread_notify_file_changed,
+				       g_strdup (info->image_uri));
+ 			continue;
+		}
 
 		/* Create the thumbnail. */
 #ifdef DEBUG_THUMBNAILS
