@@ -305,14 +305,26 @@ action_close_all_folders_callback (GtkAction *action,
 }
 
 static void
-real_prompt_for_location (NautilusWindow *window)
+real_prompt_for_location (NautilusWindow *window,
+			  const char     *initial)
 {
 	GtkWidget *dialog;
 	
 	dialog = nautilus_location_dialog_new (window);
+	if (initial != NULL) {
+		nautilus_location_dialog_set_location (NAUTILUS_LOCATION_DIALOG (dialog),
+						       initial);
+	}
+		
 	gtk_widget_show (dialog);
 }
 
+static char *
+real_get_icon_name (NautilusWindow *window)
+{
+	return nautilus_icon_factory_get_icon_for_file (window->details->viewed_file, FALSE);
+}
+
 static void
 real_set_title (NautilusWindow *window, const char *title)
 {
@@ -436,13 +448,22 @@ got_file_info_for_location_menu_callback (NautilusFile *file,
 {	
 	GtkWidget *icon;
 	GtkWidget *menu_item = callback_data;
+	GdkPixbuf *pixbuf;
 	char *icon_name;
 
 	g_return_if_fail (NAUTILUS_IS_FILE (file));
 
+	pixbuf = NULL;
+
 	icon_name = nautilus_icon_factory_get_icon_for_file (file, FALSE);
-	if (icon_name) {
-		icon = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
+	if (icon_name != NULL) {
+		pixbuf = nautilus_icon_factory_get_pixbuf_from_name_with_stock_size (icon_name, NULL, GTK_ICON_SIZE_MENU, NULL);
+		g_free (icon_name);
+	}
+
+	if (pixbuf != NULL) {
+		icon = gtk_image_new_from_pixbuf (pixbuf);
+		gdk_pixbuf_unref (pixbuf);
 	} else {
 		icon = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
 	}
@@ -594,7 +615,7 @@ location_button_drag_begin_callback (GtkWidget             *widget,
 	GdkPixbuf *pixbuf;
 
 	pixbuf = nautilus_icon_factory_get_pixbuf_for_file (NAUTILUS_WINDOW (window)->details->viewed_file,
-							    "open", get_dnd_icon_size (window));
+							    "open", get_dnd_icon_size (window), FALSE);
 
 	gtk_drag_set_icon_pixbuf (context, pixbuf, 0, 0);
 
@@ -668,12 +689,19 @@ nautilus_spatial_window_set_location_button  (NautilusSpatialWindow *window,
 		vfs_result_code = nautilus_file_get_file_info_result (file);
 		if (vfs_result_code == GNOME_VFS_OK) {
 			char *icon_name;
+			GdkPixbuf *pixbuf;
+
+			pixbuf = NULL;
 
 			icon_name = nautilus_icon_factory_get_icon_for_file (file, FALSE);		
-			if (icon_name) {
-				gtk_image_set_from_icon_name (GTK_IMAGE (window->details->location_icon), 
-							      icon_name, GTK_ICON_SIZE_MENU);
+			if (icon_name != NULL) {
+				pixbuf = nautilus_icon_factory_get_pixbuf_from_name_with_stock_size (icon_name, NULL, GTK_ICON_SIZE_MENU, NULL);
 				g_free (icon_name);
+			}
+
+			if (pixbuf != NULL) {
+				gtk_image_set_from_pixbuf (GTK_IMAGE (window->details->location_icon),  pixbuf);
+				gdk_pixbuf_unref (pixbuf);
 			} else {
 				gtk_image_set_from_stock (GTK_IMAGE (window->details->location_icon),
 							  GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
@@ -701,8 +729,8 @@ action_go_to_location_callback (GtkAction *action,
 
 	window = NAUTILUS_WINDOW (user_data);
 
-	nautilus_window_prompt_for_location (window);
-}			   
+	nautilus_window_prompt_for_location (window, NULL);
+}
 
 static void
 action_add_bookmark_callback (GtkAction *action,
@@ -755,10 +783,10 @@ nautilus_spatial_window_instance_init (NautilusSpatialWindow *window)
 		gtk_hbox_new (FALSE, 0);
 	gtk_table_attach (GTK_TABLE (NAUTILUS_WINDOW (window)->details->table),
 			  window->details->content_box,
-			  /* X direction */       /* Y direction */
-			  0, 1,                   1, 4,
-			  GTK_EXPAND | GTK_FILL,  GTK_EXPAND | GTK_FILL,
-			  0,                      0);
+			  /* X direction */                   /* Y direction */
+			  0, 1,                               1, 4,
+			  GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_EXPAND | GTK_FILL | GTK_SHRINK,
+			  0,                                  0);
 	gtk_widget_show (window->details->content_box);
 
 	window->details->location_button = gtk_button_new ();
@@ -853,6 +881,8 @@ nautilus_spatial_window_class_init (NautilusSpatialWindowClass *class)
 
 	NAUTILUS_WINDOW_CLASS (class)->prompt_for_location = 
 		real_prompt_for_location;
+	NAUTILUS_WINDOW_CLASS (class)->get_icon_name =
+		real_get_icon_name;
 	NAUTILUS_WINDOW_CLASS (class)->set_title = 
 		real_set_title;
 	NAUTILUS_WINDOW_CLASS (class)->set_content_view_widget = 
